==> qtjambi-xml-5.15.14-sources.jar: io/qt/xml/QDomText.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents text data in the parsed XML document</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdomtext.html">QDomText</a></p>
 */
public class QDomText extends io.qt.xml.QDomCharacterData
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomtext.html#QDomText">QDomText::QDomText()</a></p>
     */
    public QDomText(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomText instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomtext.html#QDomText-1">QDomText::QDomText(QDomText)</a></p>
     */
    public QDomText(io.qt.xml.@NonNull QDomText x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomText instance, io.qt.xml.QDomText x);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomtext.html#operator-eq">QDomText::operator=(QDomText)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomText arg__1){
        assign_native_cref_QDomText(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomText(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomtext.html#splitText">QDomText::splitText(int)</a></p>
     */
    @QtUninvokable
    public final io.qt.xml.@NonNull QDomText splitText(int offset){
        return splitText_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), offset);
    }
    
    @QtUninvokable
    private native io.qt.xml.QDomText splitText_native_int(long __this__nativeId, int offset);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomText(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomText clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomText clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.2.1-sources.jar: io/qt/xml/QDomText.java <==
package io.qt.xml;


/**
 * <p>Represents text data in the parsed XML document</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qdomtext.html">QDomText</a></p>
 */
public class QDomText extends io.qt.xml.QDomCharacterData
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomtext.html#QDomText">QDomText::QDomText()</a></p>
     */
    public QDomText(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomText instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomtext.html#QDomText-1">QDomText::QDomText(QDomText)</a></p>
     */
    public QDomText(io.qt.xml.QDomText x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomText instance, io.qt.xml.QDomText x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomtext.html#splitText">QDomText::splitText(int)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xml.QDomText splitText(int offset){
        return splitText_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), offset);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xml.QDomText splitText_native_int(long __this__nativeId, int offset);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomText(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomText clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomText clone_native(long __this_nativeId);
}
